@@ -176,8 +176,12 @@ class Kanata(BaseDispatcher):
         match_result = Kanata.detect_index(signature_chain, message_chain)
         if match_result is not None:
             return {k: message_chain[v[0]:(
-                v[1][0], 
-                (v[1][1] - origin_or_zero(v[0][1])) if v[1][1] is not None else None
+                v[1][0],
+                (v[1][1] - (origin_or_zero(v[0][1]) if any([
+                    v[0][0] + 1 == v[1][0],
+                    v[0][0] == v[1][0],
+                    v[0][0] - 1 == v[1][0]
+                ]) else 0)) if v[1][1] is not None else None
             )] for k, v in match_result.items()}
     
     @staticmethod
@@ -230,8 +234,6 @@ class Kanata(BaseDispatcher):
                 return
         else:
             yield Force(result)
-            # 自动清理.
-        self.parsed_items = None
     
     def after_execute(self):
         self.parsed_items = None
\ No newline at end of file
